@@ -91,6 +91,7 @@
 #'   dB = "B", col.clm = "colors", t.mar = 0.07, f.mar = 1, interactive = 2)
 #' }
 #' 
+#' @references {Araya-Salas, M., & Smith-Vidaurre, G. (2017). warbleR: An R package to streamline analysis of animal acoustic signals. Methods in Ecology and Evolution, 8(2), 184-191.}
 #' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu}) and Grace Smith Vidaurre
 #last modification on jul-5-2016 (MAS)
 
@@ -107,7 +108,7 @@ color.spectro <- function(wave, wl = 512, wn = "hanning", ovlp = 70,
   argms <- methods::formalArgs(color.spectro)
   
   # get warbleR options
-  opt.argms <- .Options$warbleR
+  opt.argms <- if(!is.null(getOption("warbleR"))) getOption("warbleR") else SILLYNAME <- 0
   
   # remove options not as default in call and not in function arguments
   opt.argms <- opt.argms[!sapply(opt.argms, is.null) & names(opt.argms) %in% argms]
