@@ -49,6 +49,7 @@
 #' # consolidate(path = tempdir())
 #' }
 #' 
+#' @references {Araya-Salas, M., & Smith-Vidaurre, G. (2017). warbleR: An R package to streamline analysis of animal acoustic signals. Methods in Ecology and Evolution, 8(2), 184-191.}
 #' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu})
 #last modification on jan-29-2018 (MAS)
 
@@ -65,7 +66,7 @@ consolidate <- function(files = NULL, path = NULL, dest.path = NULL, pb = TRUE,
   argms <- methods::formalArgs(consolidate)
   
   # get warbleR options
-  opt.argms <- .Options$warbleR
+  opt.argms <- if(!is.null(getOption("warbleR"))) getOption("warbleR") else SILLYNAME <- 0
   
   # remove options not as default in call and not in function arguments
   opt.argms <- opt.argms[!sapply(opt.argms, is.null) & names(opt.argms) %in% argms]
