@@ -1,6 +1,6 @@
 #' Remove silence in wave files
 #'
-#' \code{rm_sil} 
+#' \code{rm_sil} Removes silences in wave files
 #' @usage rm_sil(path = NULL, min.sil.dur = 2, img = TRUE, it = "jpeg", flim = c(0, 12), 
 #' flist = NULL, parallel = 1, pb = TRUE)
 #' @param path Character string containing the directory path where the sound files are located. 
@@ -18,12 +18,12 @@
 #' It specifies the number of cores to be used. Default is 1 (i.e. no parallel computing).
 #' @param pb Logical argument to control progress bar and messages. Default is \code{TRUE}. 
 #' @return Sound files for which silence segments have been removed are saved in the new 
-#' folder "removed_silence_files". If `img = TRUE` then spectrogram images highlighting the silence segments 
+#' folder "silence-removed_files". If `img = TRUE` then spectrogram images highlighting the silence segments 
 #' that were removed are also saved. 
 #' @export
 #' @name rm_sil
 #' @details The function removes silence segments (i.e. segments with very low amplitude values) from wave files. 
-#' @seealso \code{\link{fixwavs}}, \code{\link{autodetec}}, 
+#' @seealso \code{\link{fixwavs}}, \code{\link{autodetec}} 
 #' @examples{
 #' # Set temporary working directory
 #' # setwd(tempdir())
@@ -42,14 +42,18 @@
 #'  writeWave(object = wv1, filename = "wv1.wav", extensible = FALSE)
 #' 
 #' #remove silence
-#' rm_sil(flist = "wv1.wav")
+#' rm_sil(flist = "wv1.wav", pb = FALSE)
 #' 
-#' # OR this is tempdir was used instead
-#' # rm_sil(path = tempdir(), flist = "wv1.wav")
+#' # OR this if tempdir was used instead
+#' # rm_sil(path = tempdir(), flist = "wv1.wav", pb = FALSE)
 #' 
 #' #check this floder
 #' getwd()
 #' }
+#' 
+#' @references {
+#' Araya-Salas, M., & Smith-Vidaurre, G. (2017). warbleR: An R package to streamline analysis of animal acoustic signals. Methods in Ecology and Evolution, 8(2), 184-191.
+#' }
 #' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu})
 #last modification on mar-13-2018 (MAS)
 
@@ -69,7 +73,7 @@ rm_sil <- function(path = NULL, min.sil.dur = 2, img = TRUE, it = "jpeg", flim =
   argms <- methods::formalArgs(rm_sil)
   
   # get warbleR options
-  opt.argms <- .Options$warbleR
+  opt.argms <- if(!is.null(getOption("warbleR"))) getOption("warbleR") else SILLYNAME <- 0
   
   # rename path for sound files
   names(opt.argms)[names(opt.argms) == "wav.path"] <- "path"
@@ -118,7 +122,7 @@ rm_sil <- function(path = NULL, min.sil.dur = 2, img = TRUE, it = "jpeg", flim =
   #stop if files are not in working directory
   if (length(files) == 0) stop("all .wav files have been processed")
   
-  dir.create(file.path(getwd(), "removed_silence_files"), showWarnings = FALSE)
+  dir.create(file.path(getwd(), "silence-removed_files"), showWarnings = FALSE)
   
   rm.sil.FUN <- function(fl, f = 5000, msd = min.sil.dur, flm = flim, mg = img) {
     
@@ -146,7 +150,7 @@ rm_sil <- function(path = NULL, min.sil.dur = 2, img = TRUE, it = "jpeg", flim =
     
     if (mg)
     {
-      imgfun(filename = file.path(getwd(), "removed_silence_files", paste0(fl, ".rm.silence.", it)),  res = 160, units = "in", width = 8.5, height = 4) 
+      imgfun(filename = file.path(getwd(), "silence-removed_files", paste0(fl, ".rm.silence.", it)),  res = 160, units = "in", width = 8.5, height = 4) 
     
       par(mar = c(4, 4, 1, 1))
       spectro_wrblr_int(wv, ovlp = 0, grid = FALSE, scale = FALSE, palette = monitoR::gray.3, axisX = TRUE, fast.spec = TRUE, flim = flm)
@@ -169,8 +173,8 @@ rm_sil <- function(path = NULL, min.sil.dur = 2, img = TRUE, it = "jpeg", flim =
     
     #cut silence from file
     if (nrow(ad) > 1) {for(z in (nrow(ad) - 1):1)   wv <- deletew(wave = wv, from = ad$end[z], to = ad$start[z + 1], plot = FALSE, output = "Wave")
-    writeWave(object = wv, filename = file.path(getwd(), "removed_silence_files", fl), extensible = FALSE)
-    } else  file.copy(from = wv, to = file.path(getwd(), "removed_silence_files", fl))
+    writeWave(object = wv, filename = file.path(getwd(), "silence-removed_files", fl), extensible = FALSE)
+    } else  file.copy(from = wv, to = file.path(getwd(), "silence-removed_files", fl))
     }
   
   if (pb) cat("searching for silence segments in wave files:")
