@@ -2,17 +2,17 @@
 #'
 #' \code{specan} measures acoustic parameters on acoustic signals for which the start and end times 
 #' are provided. 
-#' @usage specan(X, bp = c(0,22), wl = 512, wl.freq = NULL, threshold = 15,
-#'  parallel = 1, fast = TRUE, path = NULL, pb = TRUE, ovlp = 50, ff.method = "seewave", 
-#' wn = "hanning", fsmooth = 0.1)
+#' @usage specan(X, bp = "frange", wl = 512, wl.freq = NULL, threshold = 15,
+#'  parallel = 1, fast = TRUE, path = NULL, pb = TRUE, ovlp = 50,
+#' wn = "hanning", fsmooth = 0.1, harmonicity = FALSE, nharmonics = 3, ...)
 #' @param X 'selection_table', 'extended_selection_table' or data frame with the following columns: 1) "sound.files": name of the .wav 
 #' files, 2) "sel": number of the selections, 3) "start": start time of selections, 4) "end": 
 #' end time of selections. The ouptut of \code{\link{manualoc}} or \code{\link{autodetec}} can
 #' be used as the input data frame.
 #' @param bp A numeric vector of length 2 for the lower and upper limits of a 
-#'   frequency bandpass filter (in kHz) or "frange" to indicate that values in bottom.freq
-#'   and top.freq columns will be used as bandpass limits. Default is c(0, 22).Lower limit of
-#'    bandpass is not applied to fundamental frequencies. 
+#'   frequency bandpass filter (in kHz) or "frange" (default) to indicate that values in bottom.freq
+#'   and top.freq columns will be used as bandpass limits.  Lower limit of
+#'    bandpass filter is not applied to fundamental frequencies. 
 #' @param wl A numeric vector of length 1 specifying the spectrogram window length. Default is 512. See 'wl.freq' for setting windows length independenlty in the frequency domain.
 #' @param wl.freq A numeric vector of length 1 specifying the window length of the spectrogram
 #' for measurements on the frecuency spectrum. Default is 512. Higher values would provide 
@@ -22,22 +22,23 @@
 #' @param parallel Numeric. Controls whether parallel computing is applied.
 #' It specifies the number of cores to be used. Default is 1 (i.e. no parallel computing).
 #' @param fast Logical. If \code{TRUE} (default) then the peakf acoustic parameter (see below) is not computed, which 
-#' substantially increases performance (~9 times faster).
+#' substantially increases performance (~9 times faster). This argument will be removed in future version.
 #' @param path Character string containing the directory path where the sound files are located. 
 #' If \code{NULL} (default) then the current working directory is used.
 #' @param pb Logical argument to control progress bar and messages. Default is \code{TRUE}.
 #' @param ovlp Numeric vector of length 1 specifying \% of overlap between two 
 #'   consecutive windows, used for fundamental frequency (using \code{\link[seewave]{fund}} or \code{\link[tuneR]{FF}}) and dominant frequency (using \code{\link[seewave]{dfreq}}). 
 #'   Default is 50. 
-#' @param ff.method Character. Selects the method used to calculate the fundamental
-#' frequency. Either 'tuneR' (using \code{\link[tuneR]{FF}}) or 'seewave' (using 
-#' \code{\link[seewave]{fund}}). Default is 'seewave'. Use trackfreqs to decide which method works the best. 
-#' 'tuneR' performs faster (and seems to be more accurate) than 'seewave'.
 #' @param wn Character vector of length 1 specifying window name. Default is hanning'. 
 #' See function \code{\link[seewave]{ftwindow}} for more options.
 #' @param fsmooth A numeric vector of length 1 to smooth the frequency spectrum with a mean
 #'  sliding window (in kHz) used for mean peak frequency detection. This help to average 
 #'  amplitude "hills" to minimize the effect of amplitude modulation. Default is 0.1.
+#' @param harmonicity Logical. If \code{TRUE} harmonicity related parameters (fundamental frequency parameters [meanfun, minfun, maxfun], hn_freq, 
+#' hn_width, harmonics and HNR) are measured. Note that measuring these parameters 
+#' considerably increases computing time.    
+#' @param nharmonics Numeric vector of length 1 setting the number of harmonics to analyze.
+#' @param ... Additional parameters to be passed to \code{\link[soundgen]{analyze}}, which measures parameters related to harmonicity.
 #' @return Data frame with 'sound.files' and 'selec' as in the input data frame, plus the following acoustic parameters: 
 #' \itemize{
 #'    \item \code{duration}: length of signal (in s)
@@ -76,17 +77,26 @@
 #'    \item \code{mindom}: minimum of dominant frequency measured across the acoustic signal
 #'    \item \code{maxdom}: maximum of dominant frequency measured across the acoustic signal 
 #'    \item \code{dfrange}: range of dominant frequency measured across the acoustic signal 
-#'    \item \code{modindx}: modulation index. Calculated as the cumulative absolute 
+#'    \item \code{modindx}: modulation index. Calculated as the cumulative absolute
 #'      difference between adjacent measurements of dominant frequencies divided
 #'      by the dominant frequency range. 1 means the signals is not modulated. 
 #'    \item \code{startdom}:  dominant frequency measurement at the start of the signal 
 #'    \item \code{enddom}: dominant frequency measurement at the end of the signal 
 #'    \item \code{dfslope}: slope of the change in dominant frequency through time ((enddom-startdom)/duration). Units are kHz/s.  
-#'    \item \code{peakf}: peak frequency. Frequency with highest energy (only generated if \code{fast = FALSE})
-#'    \item \code{meanpeakf}: Mean peak frequency. Frequency with highest energy from the 
-#'    mean spectrum (see \code{\link[seewave]{meanspec}}). Typically more consistent than peakf.
-#'    \item \code{bottom.freq}: low frequency. Low limit of frequency range (only generated if \code{frange.detec = TRUE})
-#'    \item \code{top.freq}: high frequency. High limit of frequency range (only generated if \code{frange.detec = TRUE})
+#'    \item \code{peakf}: peak frequency. Frequency with the highest energy. This 
+#'    parameter can take a considerable amount of time to measure. It's only 
+#'    generated if \code{fast = FALSE}. It provides a more accurate measure of peak
+#'    frequency than 'meanpeakf' but can be more easily affected by background noise.
+#'    \item \code{meanpeakf}: mean peak frequency. Frequency with highest energy from the 
+#'    mean frequency spectrum (see \code{\link[seewave]{meanspec}}). Typically more consistent than peakf.
+#'    \item \code{hn_freq}: mean frequency of the 'n' upper harmonics (kHz) (see \code{\link[soundgen]{analyze}}). 
+#'    Number of harmonics is defined with the argument 'nharmonics'.
+#'    \item \code{hn_width}: mean bandwidth of the 'n' upper harmonics (kHz) (see \code{\link[soundgen]{analyze}}). Number of harmonics is defined with the argument 'nharmonics'.  
+#'    \item \code{harmonics}: the amount of energy in upper harmonics, namely the 
+#'    ratio of total spectral power above 1.25 x F0 to the total spectral power 
+#'    below 1.25 x F0 (dB) (see \code{\link[soundgen]{analyze}}). Number of 
+#'    harmonics is defined with the argument 'nharmonics'.
+#'    \item \code{HNR}: harmonics-to-noise ratio (dB). A measure of the harmonic content generated by \code{\link[soundgen]{getPitchAutocor}}.
 #' }
 #' @export
 #' @name specan
@@ -94,34 +104,39 @@
 #'  directly without any additional modification. The function measures 29 acoustic parameters (if \code{fast = TRUE}) on 
 #'  each selection in the data frame. Most parameters are produced internally by 
 #'  \code{\link[seewave]{specprop}}, \code{\link[seewave]{fpeaks}}, \code{\link[seewave]{fund}},
-#'  and \code{\link[seewave]{dfreq}} from the package seewave and \code{\link[tuneR]{FF}} 
-#'  from the package tuneR. NAs are produced for fundamental and dominant 
-#'  frequency measures when there are no amplitude values above the threshold.
-
+#'  and \code{\link[seewave]{dfreq}} from the package seewave and \code{\link[soundgen]{analyze}} 
+#'  from the package soundgen. NAs are produced for fundamental and dominant 
+#'  frequency measures when there are no amplitude values above the threshold. 
+#'  Additional parameters can be provided to the internal function \code{\link[soundgen]{analyze}}, which measures parameters related to harmonicity.
 #' @examples
 #' {
 #' # First set temporary folder
-#' # setwd(tempdir())
+# setwd(tempdir())
 #' 
-#' data(list = c("Phae.long1", "Phae.long2", "Phae.long3", "Phae.long4", "selec.table"))
+#' data(list = c("Phae.long1", "Phae.long2", "Phae.long3", "selec.table"))
 #' writeWave(Phae.long1,"Phae.long1.wav")
 #' writeWave(Phae.long2,"Phae.long2.wav")
 #' writeWave(Phae.long3,"Phae.long3.wav")
-#' writeWave(Phae.long4,"Phae.long4.wav")
 #' 
-#' a <- specan(X = selec.table, bp = c(0, 22))
+#' # measure acoustic parameters
+#' sp_param <- specan(X = selec.table[1:8,], pb = FALSE)
 #' 
-#' # using a diferent threshold
-#' a <- specan(X = selec.table, bp = c(0, 22), threshold = 20)
-#' # View(a)
+#' # measuring peakf
+#' sp_param <- specan(X = selec.table[1:8,], pb = FALSE, fast = FALSE)
 #' 
+#' # measuring harmonic-related parameters using progress bar
+#' sp_param <- specan(X = selec.table[1:8,], harmonicity = TRUE)
+#' }
+#' 
+#' @references {
+#' Araya-Salas, M., & Smith-Vidaurre, G. (2017). warbleR: An R package to streamline analysis of animal acoustic signals. Methods in Ecology and Evolution, 8(2), 184-191.
 #' }
 #' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu}) and Grace Smith Vidaurre
 #last modification on mar-13-2018 (MAS)
 
-specan <- function(X, bp = c(0,22), wl = 512, wl.freq = NULL, threshold = 15,
+specan <- function(X, bp = "frange", wl = 512, wl.freq = NULL, threshold = 15,
                    parallel = 1, fast = TRUE, path = NULL, pb = TRUE, ovlp = 50, 
-                   ff.method = "seewave", wn = "hanning", fsmooth = 0.1){
+                   wn = "hanning", fsmooth = 0.1, harmonicity = FALSE, nharmonics = 3, ...){
   
   # reset working directory 
   wd <- getwd()
@@ -135,7 +150,7 @@ specan <- function(X, bp = c(0,22), wl = 512, wl.freq = NULL, threshold = 15,
   argms <- methods::formalArgs(specan)
   
   # get warbleR options
-  opt.argms <- .Options$warbleR
+  opt.argms <- if(!is.null(getOption("warbleR"))) getOption("warbleR") else SILLYNAME <- 0
   
   # rename path for sound files
   names(opt.argms)[names(opt.argms) == "wav.path"] <- "path"
@@ -171,7 +186,7 @@ specan <- function(X, bp = c(0,22), wl = 512, wl.freq = NULL, threshold = 15,
   if (any(is.na(c(X$end, X$start)))) stop("NAs found in start and/or end")  
   
   #if end or start are not numeric stop
-  if (all(class(X$end) != "numeric" & class(X$start) != "numeric")) stop("'end' and 'selec' must be numeric")
+  if (all(class(X$end) != "numeric" & class(X$start) != "numeric")) stop("'start' and 'end' must be numeric")
   
   #if any start higher than end stop
   if (any(X$end - X$start<0)) stop(paste("The start is higher than the end in", length(which(X$end - X$start<0)), "case(s)"))  
@@ -179,9 +194,6 @@ specan <- function(X, bp = c(0,22), wl = 512, wl.freq = NULL, threshold = 15,
   #if any selections longer than 20 secs warning
   if (any(X$end - X$start>20)) warning(paste(length(which(X$end - X$start>20)), "selection(s) longer than 20 sec"))
   
-  #if ff.method argument  
-  if (!any(ff.method == "seewave", ff.method == "tuneR")) stop(paste("ff.method", ff.method, "is not recognized")) 
-  
   # bp checking
   if (bp[1] != "frange")
   {if (!is.vector(bp)) stop("'bp' must be a numeric vector of length 2") else{
@@ -218,6 +230,8 @@ specan <- function(X, bp = c(0,22), wl = 512, wl.freq = NULL, threshold = 15,
 
   #create function to run within Xapply functions downstream
   spFUN <- function(i, X, bp, wl, threshold) { 
+    
+    # read wave object
     r <- read_wave(X = X, index = i)
     
     if (bp[1] == "frange") b <- c(X$bottom.freq[i], X$top.freq[i]) else b <- bp
@@ -225,19 +239,49 @@ specan <- function(X, bp = c(0,22), wl = 512, wl.freq = NULL, threshold = 15,
      #in case bp its higher than can be due to sampling rate
     if (b[2] > ceiling(r@samp.rate/2000) - 1) b[2] <- ceiling(r@samp.rate/2000) - 1 
     
+    # add a bit above and below to ensure range limits are included
     bpfr <- b
     bpfr <- bpfr + c(-0.2, 0.2)  
     if (bpfr[1] < 0) bpfr[1] <- 0
     if (bpfr[2] > ceiling(r@samp.rate/2000) - 1) bpfr[2] <- ceiling(r@samp.rate/2000) - 1 
-    
-  frng <- frd_wrblr_int(wave = r, wl = wl.freq, fsmooth = fsmooth, threshold = threshold, wn = wn, flim = b, bp = bpfr, ovlp = ovlp)
   
+    # freq range to measure peak freq  
+    # wl is adjusted when very short signals
+    frng <- frd_wrblr_int(wave = r, wl = wl.freq, fsmooth = fsmooth, threshold = threshold, wn = wn, flim = b, bp = bpfr, ovlp = ovlp)
+  
+    # soungen measurements
+    if (harmonicity)
+    {
+    sg.param <- soundgen::analyze(x = as.numeric(r@left), samplingRate = r@samp.rate, silence = threshold / 100, overlap = ovlp, windowLength = wl / r@samp.rate * 1000, plot = FALSE, wn = wn, pitchCeiling = b[2] * 1000, cutFreq = b[2] * 1000, nFormants = nharmonics)
+    
+  names(sg.param) <- gsub("^f", "h", names(sg.param))
+    
+  if (all(is.na(sg.param$pitch))) 
+    ff <- c(as.matrix(sg.param[, grep("pitch", names(sg.param))])) else ff <- sg.param$pitch
+
+  sg.param[, grep("freq$|_width$", names(sg.param))] <- sg.param[, grep("freq$|_width$", names(sg.param))] / 1000
+  
+  sg.param <- as.data.frame(t(apply(sg.param[, grep("harmonics|HNR|_freq$|_width$", names(sg.param))], 2, mean, na.rm = TRUE)))
+    
+  ff <- ff[!is.na(ff)]
+  
+  if (length(ff) > 0)
+  { 
+    meanfun<-mean(ff, na.rm = TRUE) / 1000
+    minfun<-min(ff, na.rm = TRUE) / 1000
+    maxfun<-max(ff, na.rm = TRUE) / 1000} else meanfun <- minfun <- maxfun <- NA
+  
+  fun.pars <- data.frame(t(c(meanfun = meanfun, minfun = minfun, maxfun = maxfun)))
+  }
+      
     #frequency spectrum analysis
     songspec <- seewave::spec(r, f = r@samp.rate, plot = FALSE, wl = wl.freq, wn = wn, flim = b)
     analysis <- seewave::specprop(songspec, f = r@samp.rate, flim = b, plot = FALSE)
 
-    #acoustat
-    m <- sspectro(r, f = r@samp.rate, wl = wl, ovlp = ovlp, wn = wn)
+    #from seewave's acoustat
+    m <- sspectro(r, f = r@samp.rate, wl = ifelse(wl >= length(r@left), length(r@left) - 1, wl), ovlp = ovlp, wn = wn)
+    if (!is.matrix(m)) m <- as.matrix(m)
+    
     fl <- b * nrow(m) * 2000/r@samp.rate
     m <- m[(fl[1]:fl[2]) + 1, ]
     if (is.vector(m)) m <- t(as.matrix(m))
@@ -266,30 +310,23 @@ specan <- function(X, bp = c(0,22), wl = 512, wl.freq = NULL, threshold = 15,
     entropy <- sp.ent * time.ent
     sfm <- analysis$sfm
     
+    options(warn = -1)
+    
     #Frequency with amplitude peaks 
     if (!fast) #only if fast is TRUE
       peakf <- seewave::fpeaks(songspec, f = r@samp.rate, wl = wl.freq, nmax = 3, plot = FALSE)[1, 1] else peakf <- NA
     
-    options(warn = -1)
     #Fundamental frequency parameters
-    if (ff.method == "seewave")
-    ff <- seewave::fund(r, f = r@samp.rate, ovlp = ovlp, threshold = threshold, 
-                        fmax = b[2] * 1000, plot = FALSE)[, 2] else {
-                        if (!any(methods::slotNames(r) == "stereo")) r <- Wave(r) 
-      ff <- tuneR::FF(tuneR::periodogram(mono(r, "left"), width = wl, 
-        overlap = wl*ovlp/100), peakheight = (100 - threshold) / 100)/1000
-                                     }
-    
-  ff <- ff[!is.na(ff)]
-    
-  if (length(ff) > 0)
-   { 
-    meanfun<-mean(ff, na.rm = TRUE)
-    minfun<-min(ff, na.rm = TRUE)
-    maxfun<-max(ff, na.rm = TRUE)} else meanfun <- minfun <- maxfun <- NA
-    
+  #   if (ff.method == "seewave")
+  #   ff <- seewave::fund(r, f = r@samp.rate, ovlp = ovlp, threshold = threshold, 
+  #                       fmax = b[2] * 1000, plot = FALSE)[, 2] else {
+  #                       if (!any(methods::slotNames(r) == "stereo")) r <- Wave(r) 
+  #     ff <- tuneR::FF(tuneR::periodogram(mono(r, "left"), width = wl, 
+  #       overlap = wl*ovlp/100), peakheight = (100 - threshold) / 100)/1000
+  #                                    }
+  
     #Dominant frecuency parameters
-    y <- seewave::dfreq(r, f = r@samp.rate, wl = wl, ovlp = ovlp, plot = FALSE, threshold = threshold, bandpass = b * 1000, fftw = TRUE)[, 2]
+    y <- seewave::dfreq(r, f = r@samp.rate, wl = ifelse(wl >= length(r@left), length(r@left) - 1, wl), ovlp = ovlp, plot = FALSE, threshold = threshold, bandpass = b * 1000, fftw = TRUE)[, 2]
     
     #remove NAs
     y <- y[!is.na(y)]
@@ -314,14 +351,17 @@ specan <- function(X, bp = c(0,22), wl = 512, wl.freq = NULL, threshold = 15,
     dfslope <- (enddom -startdom)/duration else dfslope <- NA
     meanpeakf <- frng$meanpeakf 
     
-
     #save results
     dfres <- data.frame(sound.files = X$sound.files[i], selec = X$selec[i], duration, meanfreq, sd, freq.median, freq.Q25, freq.Q75, freq.IQR, time.median, time.Q25, time.Q75, time.IQR, skew, kurt, sp.ent, time.ent, entropy, sfm, 
-                        meanfun, minfun, maxfun, meandom, mindom, maxdom, dfrange, modindx, startdom, enddom, dfslope, meanpeakf)
+                        meandom, mindom, maxdom, dfrange, modindx, startdom, enddom, dfslope, meanpeakf)
     
     # add peak freq
     if (!fast) dfres$peakf <- peakf
     
+    # add soundgen parameters
+    if (harmonicity)
+    dfres <- cbind(dfres, sg.param, fun.pars)
+    
     # add low high freq
     if (bp[1] == "frange") {
       dfres$bottom.freq <- b[1]
